"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _classnames = _interopRequireDefault(require("classnames"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && Object.prototype.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const Collapsible = _ref => {
  let {
    children,
    className,
    accordion,
    options,
    defaultActiveKey,
    popout,
    onSelect,
    ...props
  } = _ref;
  const _collapsible = (0, _react.useRef)(null);
  const collapsible = accordion ? 'accordion' : 'expandable';
  const [activeKey, setActiveKey] = (0, _react.useState)(defaultActiveKey);
  const renderItem = (child, key) => {
    if (!child) return null;

    // Extend with props if child is a react component
    if (typeof child.type === 'function') {
      Object.assign(props, {
        expanded: activeKey === key || child.props.expanded,
        eventKey: key
      });
    }
    return /*#__PURE__*/_react.default.cloneElement(child, {
      onSelect: () => handleSelect(key)
    });
  };
  const handleSelect = key => {
    if (onSelect) {
      onSelect(key);
    }
    if (activeKey === key) {
      setActiveKey(null);
    }
    if (accordion) {
      setActiveKey(key);
    }
  };
  (0, _react.useEffect)(() => {
    if (typeof M !== 'undefined') {
      const instance = M.Collapsible.init(_collapsible.current, {
        accordion: accordion,
        ...options
      });
      return () => {
        instance && instance.destroy();
      };
    }
  }, [_collapsible, accordion, options, children]);
  return /*#__PURE__*/_react.default.createElement("ul", _extends({
    ref: _collapsible,
    className: (0, _classnames.default)(className, {
      collapsible,
      expandable: accordion !== true,
      popout
    }),
    "data-collapsible": collapsible
  }, props), _react.Children.map(children, renderItem));
};
Collapsible.propTypes = {
  /**
   * There are two ways a collapsible can behave. It can either allow multiple sections to stay open,
   * or it can only allow one section to stay open at a time, which is called an accordion.
   * @default true
   */
  accordion: _propTypes.default.bool,
  className: _propTypes.default.string,
  children: _propTypes.default.node,
  /**
   * Enable popout style
   */
  popout: _propTypes.default.bool,
  /**
   * The default CollapsibleItem that should be expanded. This value should match the specified
   * item's eventKey value. Ignored if accordion is false.
   */
  defaultActiveKey: _propTypes.default.any,
  onSelect: _propTypes.default.func,
  /**
   * Options passed to initializer
   */
  options: _propTypes.default.any
};
Collapsible.defaultProps = {
  accordion: true
};
var _default = exports.default = Collapsible;