"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.dropdownOptions = exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _idgen = _interopRequireDefault(require("./idgen"));
var _classnames = _interopRequireDefault(require("classnames"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && Object.prototype.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const Dropdown = _ref => {
  let {
    children,
    className,
    trigger,
    options,
    ...props
  } = _ref;
  const _dropdownContent = (0, _react.useRef)(null);
  (0, _react.useEffect)(() => {
    const instance = M.Dropdown.init(document.querySelector(`[data-target="${props.id}"]`), options);
    return () => {
      instance && instance.destroy();
    };
  }, [options, props.id, children]);
  const renderTrigger = () => /*#__PURE__*/(0, _react.cloneElement)(trigger, {
    'data-target': props.id,
    className: (0, _classnames.default)(trigger.props.className, 'dropdown-trigger')
  });
  const renderItems = c => _react.Children.map(c, element => {
    if (!element || element.type === 'li') {
      // Skip null, undefined, or li children
      return element;
    } else if (element.type === _react.Fragment) {
      // Recurse here for Fragments
      return renderItems(element.props.children);
    } else if (element.type.name === 'Divider' || element.type.displayName === 'Divider') {
      // Replace <Divider/> component with proper semantics
      return /*#__PURE__*/_react.default.createElement("li", {
        key: (0, _idgen.default)(),
        className: "divider",
        tabIndex: "-1"
      });
    } else {
      // Wrap child element in <li/>
      return /*#__PURE__*/_react.default.createElement("li", {
        key: (0, _idgen.default)()
      }, element);
    }
  });
  return /*#__PURE__*/_react.default.createElement(_react.Fragment, null, renderTrigger(), /*#__PURE__*/_react.default.createElement("ul", _extends({}, props, {
    className: (0, _classnames.default)('dropdown-content', className),
    ref: _dropdownContent
  }), renderItems(children)));
};
const dropdownOptions = exports.dropdownOptions = _propTypes.default.shape({
  alignment: _propTypes.default.oneOf(['left', 'right']),
  autoTrigger: _propTypes.default.bool,
  constrainWidth: _propTypes.default.bool,
  container: _propTypes.default.node,
  coverTrigger: _propTypes.default.bool,
  closeOnClick: _propTypes.default.bool,
  hover: _propTypes.default.bool,
  inDuration: _propTypes.default.number,
  outDuration: _propTypes.default.number,
  onOpenStart: _propTypes.default.func,
  onOpenEnd: _propTypes.default.func,
  onCloseStart: _propTypes.default.func,
  onCloseEnd: _propTypes.default.func
});
Dropdown.propTypes = {
  id: _propTypes.default.string,
  /**
   * The node to trigger the dropdown
   */
  trigger: _propTypes.default.node.isRequired,
  children: _propTypes.default.node,
  className: _propTypes.default.string,
  /**
   * Options hash for the dropdown
   * <a target="_blank" href="http://materializecss.com/dropdown.html#options">http://materializecss.com/dropdown.html</a>
   */
  options: dropdownOptions
};
Dropdown.defaultProps = {
  get id() {
    return `Dropdown_${(0, _idgen.default)()}`;
  },
  options: {
    alignment: 'left',
    autoTrigger: true,
    constrainWidth: true,
    container: null,
    coverTrigger: true,
    closeOnClick: true,
    hover: false,
    inDuration: 150,
    outDuration: 250,
    onOpenStart: null,
    onOpenEnd: null,
    onCloseStart: null,
    onCloseEnd: null
  }
};
var _default = exports.default = Dropdown;