"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactDom = require("react-dom");
var _propTypes = _interopRequireDefault(require("prop-types"));
var _classnames = _interopRequireDefault(require("classnames"));
var _idgen = _interopRequireDefault(require("./idgen"));
var _Button = _interopRequireDefault(require("./Button"));
var _utils = require("./utils");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && Object.prototype.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const Modal = _ref => {
  let {
    actions,
    bottomSheet,
    children,
    fixedFooter,
    header,
    className,
    trigger,
    options,
    open,
    root,
    ...props
  } = _ref;
  const _modalRoot = (0, _react.useRef)(null);
  const _modalInstance = (0, _react.useRef)(null);
  const _modalRef = (0, _react.useRef)(null);
  if (root === null) {
    console.warn('React Materialize: root should be a valid node element to render a Modal');
  }
  (0, _react.useEffect)(() => {
    const modalRoot = _modalRoot.current;
    if (!_modalInstance.current) {
      _modalInstance.current = M.Modal.init(_modalRef.current, options);
    }
    return () => {
      if (root.contains(modalRoot)) {
        root.removeChild(modalRoot);
      }
      _modalInstance.current.destroy();
    };
    // deep comparing options object
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [(0, _utils.safeJSONStringify)(options), root]);
  (0, _react.useEffect)(() => {
    if (open) {
      showModal();
    } else {
      hideModal();
    }
  }, [open]);
  const showModal = e => {
    e && e.preventDefault();
    _modalInstance.current && _modalInstance.current.open();
  };
  const hideModal = e => {
    e && e.preventDefault();
    _modalInstance.current && _modalInstance.current.close();
  };
  const classes = (0, _classnames.default)('modal', {
    'modal-fixed-footer': fixedFooter,
    'bottom-sheet': bottomSheet
  }, className);
  const renderModalPortal = () => {
    if (!_modalRoot.current) {
      _modalRoot.current = document.createElement('div');
      root.appendChild(_modalRoot.current);
    }
    return /*#__PURE__*/(0, _reactDom.createPortal)( /*#__PURE__*/_react.default.createElement("div", _extends({
      className: classes,
      ref: _modalRef
    }, props), /*#__PURE__*/_react.default.createElement("div", {
      className: "modal-content"
    }, /*#__PURE__*/_react.default.createElement("h4", null, header), children), /*#__PURE__*/_react.default.createElement("div", {
      className: "modal-footer"
    }, _react.Children.toArray(actions))), _modalRoot.current);
  };
  return /*#__PURE__*/_react.default.createElement(_react.Fragment, null, trigger && /*#__PURE__*/(0, _react.cloneElement)(trigger, {
    onClick: showModal
  }), renderModalPortal());
};
Modal.propTypes = {
  /**
   * Options
   * Object with options for modal
   */
  options: _propTypes.default.shape({
    /**
     * Opacity of the modal overlay.
     */
    opacity: _propTypes.default.number,
    /**
     * Transition in duration in milliseconds.
     */
    inDuration: _propTypes.default.number,
    /**
     * Transition out duration in milliseconds.
     */
    outDuration: _propTypes.default.number,
    /**
     * Callback function called before modal is opened.
     */
    onOpenStart: _propTypes.default.func,
    /**
     * Callback function called after modal is opened.
     */
    onOpenEnd: _propTypes.default.func,
    /**
     * Callback function called before modal is closed.
     */
    onCloseStart: _propTypes.default.func,
    /**
     * Callback function called after modal is closed.
     */
    onCloseEnd: _propTypes.default.func,
    /**
     * Prevent page from scrolling while modal is open.
     */
    preventScrolling: _propTypes.default.bool,
    /**
     * Allow modal to be dismissed by keyboard or overlay click.
     */
    dismissible: _propTypes.default.bool,
    /**
     * Starting top offset
     */
    startingTop: _propTypes.default.string,
    /**
     * Ending top offset
     */
    endingTop: _propTypes.default.string
  }),
  /**
   * Extra class to added to the Modal
   */
  className: _propTypes.default.string,
  /**
   * Modal is opened on mount
   * @default false
   */
  open: _propTypes.default.bool,
  /**
   * BottomSheet styled modal
   * @default false
   */
  bottomSheet: _propTypes.default.bool,
  /**
   * Component children
   */
  children: _propTypes.default.node,
  /**
   * FixedFooter styled modal
   * @default false
   */
  fixedFooter: _propTypes.default.bool,
  /**
   * Text to shown in the header of the modal
   */
  header: _propTypes.default.string,
  /**
   * The button to trigger the display of the modal
   */
  trigger: _propTypes.default.node,
  /**
   * The buttons to show in the footer of the modal
   * @default <Button>Close</Button>
   */
  actions: _propTypes.default.node,
  /**
   * The ID to trigger the modal opening/closing
   */
  id: _propTypes.default.string,
  /**
   * Root node where modal should be injected
   * @default document.body
   */
  root: _propTypes.default.any
};
Modal.defaultProps = {
  get id() {
    return `Modal-${(0, _idgen.default)()}`;
  },
  root: typeof window !== 'undefined' ? document.body : null,
  open: false,
  options: {
    opacity: 0.5,
    inDuration: 250,
    outDuration: 250,
    onOpenStart: null,
    onOpenEnd: null,
    onCloseStart: null,
    onCloseEnd: null,
    preventScrolling: true,
    dismissible: true,
    startingTop: '4%',
    endingTop: '10%'
  },
  fixedFooter: false,
  bottomSheet: false,
  actions: [/*#__PURE__*/_react.default.createElement(_Button.default, {
    waves: "green",
    modal: "close",
    flat: true
  }, "Close")]
};
var _default = exports.default = Modal;