"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _classnames = _interopRequireDefault(require("classnames"));
var _Icon = _interopRequireDefault(require("./Icon"));
var _PaginationButton = _interopRequireDefault(require("./PaginationButton"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && Object.prototype.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const Pagination = _ref => {
  let {
    items,
    className,
    children,
    maxButtons = items,
    leftBtn,
    rightBtn,
    onSelect,
    activePage: activePageProp
  } = _ref;
  const [activePage, setActivePage] = (0, _react.useState)(activePageProp > 0 && activePageProp <= items ? activePageProp : 1);
  (0, _react.useEffect)(() => {
    setActivePage(activePageProp);
  }, [activePageProp]);
  const onClick = (0, _react.useCallback)(pageIdx => {
    if (pageIdx > 0 && pageIdx <= items) {
      if (onSelect) onSelect(pageIdx);
      setActivePage(pageIdx);
    }
  }, [onSelect, items]);
  const renderButtons = (0, _react.useMemo)(() => {
    if (children) return children;
    const buttonsCount = Math.min(maxButtons, items);
    const maxPos = items - buttonsCount;
    const halfButtons = parseInt(buttonsCount / 2, 10);
    let hiddenPagesBefore = activePage - halfButtons;
    if (hiddenPagesBefore > maxPos) {
      hiddenPagesBefore = maxPos + 1;
    }
    let from = Math.max(hiddenPagesBefore, 1);
    let to = Math.min(items, from + maxButtons - 1);
    const buttons = [/*#__PURE__*/_react.default.createElement(_PaginationButton.default, {
      disabled: activePage === 1,
      key: 'pagination-0',
      onSelect: () => onClick(activePage - 1)
    }, leftBtn)];
    for (let i = from; i <= to; i++) {
      buttons.push( /*#__PURE__*/_react.default.createElement(_PaginationButton.default, {
        active: i === activePage,
        key: `pagination-${i}`,
        onSelect: () => onClick(i)
      }, i));
    }
    buttons.push( /*#__PURE__*/_react.default.createElement(_PaginationButton.default, {
      key: `pagination-${items + 1}`,
      disabled: activePage === items,
      onSelect: () => onClick(activePage + 1)
    }, rightBtn));
    return buttons;
  }, [children, maxButtons, items, activePage, onClick, leftBtn, rightBtn]);
  return /*#__PURE__*/_react.default.createElement("ul", {
    className: (0, _classnames.default)('pagination', className)
  }, renderButtons);
};
Pagination.propTypes = {
  /**
   * Number of items in the component
   */
  items: _propTypes.default.number.isRequired,
  /**
   * The initial activePage
   */
  activePage: _propTypes.default.number,
  children: _propTypes.default.node,
  className: _propTypes.default.string,
  maxButtons: _propTypes.default.number,
  onSelect: _propTypes.default.func,
  leftBtn: _propTypes.default.node,
  rightBtn: _propTypes.default.node
};
Pagination.defaultProps = {
  activePage: 1,
  items: 10,
  leftBtn: /*#__PURE__*/_react.default.createElement(_Icon.default, null, "chevron_left"),
  rightBtn: /*#__PURE__*/_react.default.createElement(_Icon.default, null, "chevron_right")
};
var _default = exports.default = Pagination;