"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _classnames = _interopRequireDefault(require("classnames"));
var _idgen = _interopRequireDefault(require("./idgen"));
var _constants = _interopRequireDefault(require("./constants"));
var _Dropdown = require("./Dropdown");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && Object.prototype.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const Select = _ref => {
  let {
    id,
    s,
    m,
    l,
    xl,
    noLayout,
    browserDefault,
    icon,
    label,
    className,
    success,
    error,
    validate,
    children,
    multiple,
    options,
    value,
    onChange,
    ...props
  } = _ref;
  const [selectedValue, setSelectedValue] = (0, _react.useState)(value);
  const _selectRef = (0, _react.useRef)(null);
  const _formSelectInstance = (0, _react.useRef)(null);
  (0, _react.useEffect)(() => {
    _formSelectInstance.current = M.FormSelect.init(_selectRef.current, options);
    return () => {
      _formSelectInstance.current && _formSelectInstance.current.destroy();
    };
  }, [options, children]);
  (0, _react.useEffect)(() => {
    setSelectedValue(value);
  }, [value]);
  const sizes = {
    s,
    m,
    l,
    xl
  };
  let responsiveClasses = {};
  if (!noLayout) {
    responsiveClasses = {
      col: true
    };
    _constants.default.SIZES.forEach(size => {
      responsiveClasses[size + sizes[size]] = sizes[size];
    });
  }
  const renderOption = child => /*#__PURE__*/(0, _react.cloneElement)(child, {
    key: child.props.value
  });
  const handleChange = e => {
    let value = e.target.value;
    if (multiple) {
      value = _formSelectInstance.current.getSelectedValues();
    }
    onChange && onChange(e);
    setSelectedValue(value);
  };
  return /*#__PURE__*/_react.default.createElement("div", {
    className: (0, _classnames.default)('input-field', responsiveClasses)
  }, Boolean(icon) && /*#__PURE__*/(0, _react.cloneElement)(icon, {
    className: 'prefix'
  }), /*#__PURE__*/_react.default.createElement("select", _extends({}, props, {
    id: id,
    value: selectedValue,
    ref: _selectRef,
    onChange: handleChange,
    className: (0, _classnames.default)(className, {
      validate,
      multiple,
      ['browser-default']: browserDefault
    }),
    multiple: multiple
  }), _react.Children.map(children, renderOption)), Boolean(label) && /*#__PURE__*/_react.default.createElement("label", {
    "data-success": success,
    "data-error": error,
    htmlFor: id
  }, label));
};
Select.propTypes = {
  /**
   * Use browser default styles
   */
  browserDefault: _propTypes.default.bool,
  /**
   * Strip away all layout classes such as col and sX
   */
  noLayout: _propTypes.default.bool,
  /**
   * Responsive size for small size screens (Mobile Devices <= 600px)
   */
  s: _propTypes.default.number,
  /**
   * Responsive size for middle size screens (Tablet Devices > 600px)
   */
  m: _propTypes.default.number,
  /**
   * Responsive size for large size screens (Desktop Devices > 992px)
   */
  l: _propTypes.default.number,
  /**
   * Responsive size for extra large screens (Large Desktop Devices > 1200px)
   */
  xl: _propTypes.default.number,
  /**
   * disabled input
   */
  disabled: _propTypes.default.bool,
  /**
   * override id
   * @default idgen()
   */
  id: _propTypes.default.string,
  /**
   * Select name
   */
  name: _propTypes.default.string,
  /**
   * prefix icon
   */
  icon: _propTypes.default.node,
  /**
   * label text
   */
  label: _propTypes.default.string,
  /**
   * Input initial value
   */
  value: _propTypes.default.oneOfType([_propTypes.default.string, _propTypes.default.array]),
  /**
   * Add validate class to input
   */
  validate: _propTypes.default.bool,
  /**
   * Custom success message
   */
  success: _propTypes.default.string,
  /**
   * Custom error message
   */
  error: _propTypes.default.string,
  /**
   * Additional classes for input
   */
  className: _propTypes.default.string,
  /**
   * override type="text"
   */
  type: _propTypes.default.string,
  /**
   * onChange callback
   */
  onChange: _propTypes.default.func,
  /**
   * Render a multiple dropdown,
   * use instance.getSelectedValues()
   * to get array of selected values
   */
  multiple: _propTypes.default.bool,
  children: _propTypes.default.any,
  /**
   * Options for the select
   * <a target="_blank" href="https://materializecss.com/select.html#options">https://materializecss.com/select.html</a>
   */
  options: _propTypes.default.shape({
    classes: _propTypes.default.string,
    /**
     * Options for the dropdown
     * <a target="_blank" href="http://materializecss.com/dropdown.html#options">http://materializecss.com/dropdown.html</a>
     */
    dropdownOptions: _Dropdown.dropdownOptions
  })
};
Select.defaultProps = {
  get id() {
    return `Select-${(0, _idgen.default)()}`;
  },
  multiple: false,
  options: {
    classes: '',
    dropdownOptions: {
      alignment: 'left',
      autoTrigger: true,
      constrainWidth: true,
      coverTrigger: true,
      closeOnClick: true,
      hover: false,
      inDuration: 150,
      outDuration: 250,
      onOpenStart: null,
      onOpenEnd: null,
      onCloseStart: null,
      onCloseEnd: null
    }
  }
};
var _default = exports.default = Select;