"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _classnames = _interopRequireDefault(require("classnames"));
var _idgen = _interopRequireDefault(require("./idgen"));
var _constants = _interopRequireDefault(require("./constants"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && Object.prototype.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const TextInput = /*#__PURE__*/_react.default.forwardRef((props, ref) => {
  // eslint-disable-next-line react/prop-types
  const dataLength = props['data-length'];
  const inputRef = ref || /*#__PURE__*/(0, _react.createRef)(null);
  (0, _react.useEffect)(() => {
    if (inputRef && dataLength) {
      M.CharacterCounter.init(inputRef.current);
    }
  }, [dataLength, inputRef]);
  (0, _react.useEffect)(() => {
    M.updateTextFields();
  }, [props.children]);
  const {
    children,
    s,
    m,
    l,
    xl,
    disabled,
    noLayout,
    placeholder,
    icon,
    label,
    inputClassName,
    success,
    error,
    password,
    email,
    validate,
    defaultValue,
    value,
    type,
    ...other
  } = props;
  const sizes = {
    s,
    m,
    l,
    xl
  };
  let responsiveClasses;
  if (!noLayout) {
    responsiveClasses = {
      col: true
    };
    _constants.default.SIZES.forEach(size => {
      responsiveClasses[size + sizes[size]] = sizes[size];
    });
  }
  const wrapperClasses = (0, _classnames.default)('input-field', responsiveClasses);
  let computedType;
  if (type) {
    computedType = type;
  } else if (password) {
    computedType = 'password';
  } else if (email) {
    computedType = 'email';
  } else {
    computedType = 'text';
  }
  const inputProps = {
    placeholder,
    type: computedType,
    value,
    defaultValue,
    disabled,
    ...other
  };
  const renderLabel = () => label && /*#__PURE__*/_react.default.createElement("label", {
    className: (0, _classnames.default)({
      active: value || placeholder,
      'label-icon': typeof label !== 'string'
    }),
    "data-success": success,
    "data-error": error,
    htmlFor: inputProps.id
  }, label);
  const renderHelper = () => (error || success) && /*#__PURE__*/_react.default.createElement("span", {
    className: "helper-text",
    "data-error": error,
    "data-success": success
  });
  const renderIcon = () => {
    if (!icon) return;
    if (typeof icon === 'string') {
      return /*#__PURE__*/_react.default.createElement("i", {
        className: "material-icons prefix"
      }, icon);
    }
    return /*#__PURE__*/_react.default.cloneElement(icon, {
      className: 'prefix'
    });
  };
  if (type === 'file') {
    return /*#__PURE__*/_react.default.createElement("div", {
      className: `${wrapperClasses} file-field`
    }, /*#__PURE__*/_react.default.createElement("div", {
      className: "btn"
    }, /*#__PURE__*/_react.default.createElement("span", null, label), /*#__PURE__*/_react.default.createElement("input", _extends({
      type: "file",
      className: (0, _classnames.default)({
        validate
      }, inputClassName)
    }, inputProps))), /*#__PURE__*/_react.default.createElement("div", {
      className: "file-path-wrapper"
    }, /*#__PURE__*/_react.default.createElement("input", {
      className: "file-path validate",
      type: "text"
    })), renderHelper(), children);
  }
  return /*#__PURE__*/_react.default.createElement("div", {
    className: wrapperClasses
  }, renderIcon(), /*#__PURE__*/_react.default.createElement("input", _extends({
    ref: inputRef,
    className: (0, _classnames.default)({
      validate
    }, inputClassName)
  }, inputProps)), renderLabel(), renderHelper(), children);
});
TextInput.displayName = 'TextInput';
TextInput.propTypes = {
  /**
   * Strip away all layout classes such as col and sX
   */
  noLayout: _propTypes.default.bool,
  /**
   * Responsive size for Mobile Devices
   */
  s: _propTypes.default.number,
  /**
   * Responsive size for Tablet Devices
   */
  m: _propTypes.default.number,
  /**
   *  Responsive size for Desktop Devices
   */
  l: _propTypes.default.number,
  /**
   *  Responsive size for Large Desktop Devices
   */
  xl: _propTypes.default.number,
  /**
   * disabled input
   */
  disabled: _propTypes.default.bool,
  /**
   * Placeholder string
   */
  placeholder: _propTypes.default.string,
  /**
   * override id
   * @default idgen()
   */
  id: _propTypes.default.string,
  /**
   * prefix icon, name of the icon or a node
   */
  icon: _propTypes.default.node,
  /**
   * label text
   */
  label: _propTypes.default.oneOfType([_propTypes.default.string, _propTypes.default.node]),
  /**
   * Input initial value
   */
  defaultValue: _propTypes.default.string,
  /**
   * Input value
   */
  value: _propTypes.default.string,
  /**
   * Add validate class to input
   */
  validate: _propTypes.default.bool,
  /**
   * Custom success message
   */
  success: _propTypes.default.string,
  /**
   * Custom error message
   */
  error: _propTypes.default.string,
  /**
   * Additional classes for input
   */
  inputClassName: _propTypes.default.string,
  /**
   * override type="text"
   */
  type: _propTypes.default.string,
  /**
   * onChange callback
   */
  onChange: _propTypes.default.func,
  /**
   * password type
   */
  password: _propTypes.default.bool,
  /**
   * email type
   */
  email: _propTypes.default.bool,
  /**
   * children
   */
  children: _propTypes.default.node
};
TextInput.defaultProps = {
  get id() {
    return `TextInput-${(0, _idgen.default)()}`;
  }
};
var _default = exports.default = TextInput;