"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _classnames = _interopRequireDefault(require("classnames"));
var _idgen = _interopRequireDefault(require("./idgen"));
var _constants = _interopRequireDefault(require("./constants"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && Object.prototype.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const Textarea = _ref => {
  let {
    children,
    className,
    s,
    m,
    l,
    xl,
    noLayout,
    placeholder,
    icon,
    label,
    success,
    error,
    iconClassName,
    onChange,
    validate,
    defaultValue,
    value,
    id,
    ...rest
  } = _ref;
  const textareaRef = (0, _react.useRef)(null);
  const dataLength = rest['data-length'];
  (0, _react.useEffect)(() => {
    if (dataLength) {
      M.CharacterCounter.init(textareaRef.current);
    }
  }, [dataLength, children]);
  (0, _react.useEffect)(() => {
    M.textareaAutoResize(textareaRef.current);
  }, [children]);
  const sizes = {
    s,
    m,
    l,
    xl
  };
  let responsiveClasses;
  if (!noLayout) {
    responsiveClasses = {
      col: true
    };
    _constants.default.SIZES.forEach(size => {
      responsiveClasses[size + sizes[size]] = sizes[size];
    });
  }
  return /*#__PURE__*/_react.default.createElement("div", {
    className: (0, _classnames.default)('input-field', responsiveClasses)
  }, Boolean(icon) && /*#__PURE__*/_react.default.cloneElement(icon, {
    className: 'prefix'
  }), /*#__PURE__*/_react.default.createElement("textarea", _extends({
    placeholder: placeholder,
    id: id,
    value: value,
    defaultValue: defaultValue,
    ref: textareaRef,
    onChange: onChange
  }, rest, {
    className: (0, _classnames.default)('materialize-textarea', {
      validate
    }, className)
  })), Boolean(label) && /*#__PURE__*/_react.default.createElement("label", {
    className: (0, _classnames.default)({
      active: value || placeholder,
      'label-icon': typeof label !== 'string'
    }),
    "data-success": success,
    "data-error": error,
    htmlFor: id
  }, label), [error || success] && /*#__PURE__*/_react.default.createElement("span", {
    className: "helper-text",
    "data-error": error,
    "data-success": success
  }), children);
};
Textarea.propTypes = {
  children: _propTypes.default.node,
  /**
   * Strip away all layout classes such as col and sX
   */
  noLayout: _propTypes.default.bool,
  /**
   * Responsive size for Mobile Devices
   */
  s: _propTypes.default.number,
  /**
   * Responsive size for Tablet Devices
   */
  m: _propTypes.default.number,
  /**
   * Responsive size for Desktop Devices
   */
  l: _propTypes.default.number,
  /**
   *  Responsive size for Large Desktop Devices
   */
  xl: _propTypes.default.number,
  /**
   * disabled input
   */
  disabled: _propTypes.default.bool,
  /**
   * Placeholder string
   */
  placeholder: _propTypes.default.string,
  /**
   * override id
   * @default idgen()
   */
  id: _propTypes.default.string,
  /**
   * render icon next to input
   */
  icon: _propTypes.default.node,
  /**
   * icon classname
   */
  iconClassName: _propTypes.default.string,
  /**
   * textarea label
   */
  label: _propTypes.default.string,
  /**
   * Input initial value
   */
  defaultValue: _propTypes.default.string,
  /**
   * predefined value
   */
  value: _propTypes.default.string,
  /**
   * Add validate class to input
   */
  validate: _propTypes.default.bool,
  /**
   * Custom success message
   */
  success: _propTypes.default.string,
  /**
   * Custom error message
   */
  error: _propTypes.default.string,
  /**
   * textarea classname
   */
  className: _propTypes.default.string,
  /**
   * onChange callback
   */
  onChange: _propTypes.default.func
};
Textarea.defaultProps = {
  get id() {
    return `Textarea-${(0, _idgen.default)()}`;
  }
};
var _default = exports.default = Textarea;